@@ -52,7 +52,7 @@ from hcloud.networks import Network
     ],
 )
 def test_eq(value):
-    assert value == value
+    assert value.__eq__(value)
 
 
 class TestLoadBalancers:
